@@ -1,4 +1,7 @@
-def drop_categorical(df, inplace:bool=False):
+import pandas as pd
+import numpy as np
+
+def drop_categorical(df:pd.DataFrame, inplace:bool=False) -> pd.DataFrame:
 
     """
     Drop all categorical columns from the dataframe. A useful step before regression modeling, as categorical variables are not used.
@@ -18,8 +21,6 @@ def drop_categorical(df, inplace:bool=False):
     DataFrame with categorical columns dropped or None if inplace=True.
     """
 
-    import pandas as pd
-
     cats = list(df.select_dtypes(exclude="number"))
     print(f"Dropping {len(cats)} categorical columns: {cats}")
 
@@ -34,7 +35,7 @@ def drop_categorical(df, inplace:bool=False):
         return new_df
 
 
-def remove_low_variation(df=None, dv:str=None, columns:list="all", threshold:float=0.98, inplace:bool=False, verbose:bool=True):
+def remove_low_variation(df:pd.DataFrame=None, dv:str=None, columns:list="all", threshold:float=0.98, inplace:bool=False, verbose:bool=True) -> pd.DataFrame:
 
     """
     Remove columns from a dataset that do not meet the variation threshold. That is, columns will be dropped that contain a high percentage of one value.
@@ -62,8 +63,6 @@ def remove_low_variation(df=None, dv:str=None, columns:list="all", threshold:flo
     DataFrame with low variation columns dropped or None if inplace=True.
     """
 
-    import pandas as pd
-
     print("\nRemoval of Low Variance Fields\n")
 
     if columns == "all":
@@ -111,7 +110,7 @@ def remove_low_variation(df=None, dv:str=None, columns:list="all", threshold:flo
             return new_df
 
 
-def dv_proxies(df, dv:str, threshold:float=0.8, inplace:bool=False):
+def dv_proxies(df:pd.DataFrame, dv:str, threshold:float=0.8, inplace:bool=False) -> pd.DataFrame:
 
     """
     Remove columns that are highly correlated with the outcome (target) column.
@@ -135,8 +134,6 @@ def dv_proxies(df, dv:str, threshold:float=0.8, inplace:bool=False):
     DataFrame with outcome proxy columns dropped or None if inplace=True.
     """
 
-    import pandas as pd
-
     corrs = df.corr(method="pearson")[dv]
     corrs = pd.DataFrame(corrs.dropna().drop([dv], axis=0))
     corrs = corrs[corrs[dv] > threshold].index.to_list()
@@ -154,7 +151,7 @@ def dv_proxies(df, dv:str, threshold:float=0.8, inplace:bool=False):
         return new_df
 
 
-def correlation_reduction(df=None, dv:str=None, threshold:float=0.90, inplace:bool=False, verbose:bool=True):
+def correlation_reduction(df:pd.DataFrame=None, dv:str=None, threshold:float=0.90, inplace:bool=False, verbose:bool=True) -> pd.DataFrame:
 
     """
     Reduce the number of columns on a dataframe by dropping columns that are highly correlated with other columns. Note: only one of the two highly correlated columns will be dropped. uses Pearson's correlation coefficient.
@@ -180,9 +177,6 @@ def correlation_reduction(df=None, dv:str=None, threshold:float=0.90, inplace:bo
     DataFrame with half of highly correlated columns dropped or None if inplace=True.
     """
 
-    import pandas as pd
-    import numpy as np
-
     corrs = df.drop([dv], axis=1).corr()
 
     # Drop repeats by just selecting the upperhalf of the matrix
