@@ -1,4 +1,7 @@
-def marginal_effects(model, x_test, dv_description:str, field_labels:dict = None):
+import pandas as pd
+import numpy as np
+
+def marginal_effects(model, x_test:pd.DataFrame, dv_description:str, field_labels:dict = None) -> pd.DataFrame:
     """
     Calculates and returns the marginal effects at the mean (MEM) for predcitor fields.
 
@@ -17,8 +20,6 @@ def marginal_effects(model, x_test, dv_description:str, field_labels:dict = None
 
     Returns a Dataframe of marginal effects.
     """
-    import pandas as pd
-    import numpy as np
     
     #Clean up model variable names in basis function
     
@@ -253,7 +254,7 @@ def marginal_effects(model, x_test, dv_description:str, field_labels:dict = None
     return bf
 
 
-def prescriptions(model, input_df, scored_df, actionable_fields:dict, dv_description:str, field_labels=None, returned_insights:int=5, only_actionable:bool=False, explanation_fields='all'):
+def prescriptions(model, input_df:pd.DataFrame, scored_df:pd.DataFrame, actionable_fields:dict, dv_description:str, field_labels=None, returned_insights:int=5, only_actionable:bool=False, explanation_fields='all') -> pd.DataFrame:
 
     """
     Return "actionable" prescriptions and explanatory insights for each scored record. Insights first list actionable prescriptions follow by explainatory insights. This approach is recommended or linear/logistic methodologies only. Caution should be used if using a black box approach, as manpulating more than one prescription at a time could change a record's model score in unintended ways.
@@ -283,9 +284,6 @@ def prescriptions(model, input_df, scored_df, actionable_fields:dict, dv_descrip
 
 
     Returns a Dataframe of prescriptive actions. One row per record input."""
-
-    import pandas as pd
-    import numpy as np
     
     bf = pd.DataFrame(input_df.columns.tolist(), columns=['feature'])
     
@@ -446,8 +444,8 @@ def prescriptions(model, input_df, scored_df, actionable_fields:dict, dv_descrip
     #Calc abs of effect to be used for sorting
     change_score['effect_pct_abs'] = change_score['effect_pct'].abs()
     
-    #Remove features with zero effect
-    change_score = change_score[(change_score['effect_pct_abs'] > 0.0051)]
+    #Remove features with very little effect
+    change_score = change_score[(change_score['effect_pct_abs'] >= 0.05)]
         
     #Sort by index (asc), type (asc), absoulte value of effect (desc)
     change_score.sort_values(by=['type', 'effect_pct_abs'], axis=0, ascending=(True, False), inplace=True)
@@ -478,9 +476,14 @@ def prescriptions(model, input_df, scored_df, actionable_fields:dict, dv_descrip
     
     #For Actionable Features  
     if len(actionable_fields) > 0:
+        #change_score['insight'] = np.where((change_score['binary'] == False) & (change_score['type'] == 'actionable'),
+        #                                   change_score['direction']+" \'"+change_score['feature_label']+"\' by "+np.where(change_score['increase_value'] >= 1, change_score['increase_value'].astype(int).astype(str), change_score['increase_value'].astype(str))+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%."), #For non-binary
+        #                                   "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%.") #For binary 
+        #                                   )   
+        
         change_score['insight'] = np.where((change_score['binary'] == False) & (change_score['type'] == 'actionable'),
-                                           change_score['direction']+" \'"+change_score['feature_label']+"\' by "+np.where(change_score['increase_value'] >= 1, change_score['increase_value'].astype(int).astype(str), change_score['increase_value'].astype(str))+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%."), #For non-binary
-                                           "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%.") #For binary 
+                                           change_score['direction']+" \'"+change_score['feature_label']+f"\' will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%."), #For non-binary
+                                           "Changing \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%.") #For binary 
                                            )     
     
     #For Explainable (not-Actionable) Features
