@@ -1,15 +1,21 @@
+import pandas as pd
+import warnings
+import numpy as np
+import seaborn as sns
+from sklearn import metrics
+
 def model_metrics(
     model,
-    x_train,
-    y_train,
-    x_test,
-    y_test,
-    show_graphs=True,
-    f_score=0.50,
-    classification=True,
+    x_train:pd.DataFrame,
+    y_train:pd.DataFrame,
+    x_test:pd.DataFrame,
+    y_test:pd.DataFrame,
+    show_graphs:bool=True,
+    f_score:float=0.50,
+    classification:bool=True,
     algo=None,
-    decile_n = 10,
-    top_features_n=20,
+    decile_n:int = 10,
+    top_features_n:int=20,
 ):
 
     """
@@ -18,13 +24,6 @@ def model_metrics(
     See https://pypi.org/project/gitlabds/ for more information and example calls.
     """
 
-    import warnings
-
-    import numpy as np
-    import pandas as pd
-    import seaborn as sns
-    from sklearn import metrics
-
     pd.set_option("display.float_format", lambda x: "%.5f" % x)
 
     # Feature Importance
@@ -458,4 +457,4 @@ def model_metrics(
         return metricx, lift, classification_metricx, top_features
 
     else:
-        return metricx, lift, top_features
\ No newline at end of file
+        return metricx, lift, top_features
