@@ -1,4 +1,10 @@
-def split_data(df, train_pct:float=0.7, dv:str=None, dv_threshold:float=0.0, random_state:int=5435):
+import pandas as pd
+import numpy as np
+from sklearn.model_selection import train_test_split
+from imblearn.over_sampling import SMOTENC
+from sklearn.utils import resample
+
+def split_data(df:pd.DataFrame, train_pct:float=0.7, dv:str=None, dv_threshold:float=0.0, random_state:int=5435):
     """
     This function will split your data into train and test datasets, separating the outcome from the rest of the file. The resultant datasets will be named x_train,y_train, x_test, and y_test.
 
@@ -23,12 +29,6 @@ def split_data(df, train_pct:float=0.7, dv:str=None, dv_threshold:float=0.0, ran
     4 dataframes for train and test and a list of model weights.
     """
 
-    import pandas as pd
-    import numpy as np
-    from sklearn.model_selection import train_test_split
-    from imblearn.over_sampling import SMOTENC
-    from sklearn.utils import resample
-
     # Determine positive instances of the outcome percentage
     if dv != None:
         # Split Outcome From Other Fields
